@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+import re
 import sys
 from dataclasses import dataclass, field
 from pathlib import Path
@@ -5,13 +8,31 @@ from typing import List
 
 from .cui import ask_with_default_num, ask_Yn, ask_yN
 from .environment import Version
+from .exception import Emsg, PypjError
 from .type_def import Formatter, ImportSorter, Linter, Plugin, TestFramework, TypeChecker
 
 
+class PackageName(str):
+    @staticmethod
+    def is_valid(name: str) -> bool:
+        regex = r"^[a-zA-Z][0-9a-zA-Z\-_]*"
+        return bool(re.fullmatch(regex, name))
+
+    @staticmethod
+    def strict_format(package_name: str) -> str:
+        return package_name.replace("-", "_").lower()
+
+    def __new__(cls, name: str) -> PackageName:
+        if not PackageName.is_valid(name):
+            raise PypjError(Emsg.INVALID_PACKAGE_NAME)
+        self = super().__new__(cls, PackageName.strict_format(name))
+        return self
+
+
 @dataclass
 class PypjSetting(object):
     python_version: Version
-    package_name: str
+    package_name: PackageName
     max_line_length: int = 119
     # use or not
     use_src: bool = False
@@ -28,23 +49,30 @@ class PypjSetting(object):
     unittest_framework: TestFramework = TestFramework.PYTEST
     test_framework: TestFramework = TestFramework.TOX
     plugin: List[Plugin] = field(
-        default_factory=lambda: [Plugin.PYTEST_COV, Plugin.PYTEST_MOCK, Plugin.TOX_GH_ACTIONS]
+        default_factory=lambda: [
+            Plugin.FLAKE8_BUGBEAR,
+            Plugin.PYTEST_COV,
+            Plugin.PYTEST_MOCK,
+            Plugin.TOX_GH_ACTIONS,
+        ]
     )
 
     def __post_init__(self) -> None:
-        self.package_name_validate()
+        self.validate_package_dir()
+        self.src_dir: str = self.package_name  # as default
 
     def customize(self) -> None:
         self.max_line_length = ask_with_default_num("Max line length (119): ", 119)
-        self.use_src = ask_yN("Use src directory?")
-        self.venv_in_pj = ask_Yn("Keep venv in project?")
-        self.guthub_actions = ask_Yn("Use github workflows?")
-        self.vscode = ask_Yn("Use vscode settings?")
-        self.precommit = ask_Yn("Use pre-commit?")
-        self.makefile = ask_Yn("Use command alias as Makefile?")
+        self.use_src = ask_yN("Use src directory")
+        self.src_dir = "src" if self.use_src else self.package_name
+        self.venv_in_pj = ask_Yn("Keep venv in project")
+        self.guthub_actions = ask_Yn("Use github workflows")
+        self.vscode = ask_Yn("Use vscode settings")
+        self.precommit = ask_Yn("Use pre-commit")
+        self.makefile = ask_Yn("Use command alias as Makefile")
 
-    def package_name_validate(self) -> None:
-        if Path().cwd().joinpath(self.package_name).exists():
+    def validate_package_dir(self) -> None:
+        if Path().cwd().joinpath(str(self.package_name)).exists():
             print(f"ERROR: Directory {self.package_name} already exists.")
             sys.exit(1)
 
@@ -107,14 +135,14 @@ require_locked_deps = true
 install_dev_deps = true
 commands =
     poetry install -vv --no-root
-    pytest ./tests -v --cov=pypj --cov-branch --durations=0
+    pytest ./tests -v --cov=PACKAGE_DIR --cov-branch --durations=0
 [testenv:flake8]
-commands = poetry run pflake8 ./PACKAGE_DIR
+commands = poetry run pflake8 --statistics ./PACKAGE_DIR ./tests
 [testenv:black]
-commands = poetry run black ./PACKAGE_DIR
+commands = poetry run black ./PACKAGE_DIR ./tests
 [testenv:mypy]
-commands = poetry run mypy ./PACKAGE_DIR
+commands = poetry run mypy ./PACKAGE_DIR ./tests
 [testenv:isort]
-commands = poetry run isort ./PACKAGE_DIR
+commands = poetry run isort ./PACKAGE_DIR ./tests
 \"\"\"
 """
